@@ -82,13 +82,13 @@ class DiscreteEnv(gym.Env):
 #"action" argument is one value in the range of the action space (logit transform)
   def step(self, action):
     
-    self.state = self.df   #self.df.sample(n=1, random_state=1).values.reshape(3,) 
+    self.state = self.df.sample(n=1, random_state=1).values.reshape(3,) 
     
     data = []
-    for row in self.state.itertuples(index=False):    #self.df.itertuples(index=False):
-      Xs = row[0]
-      Xa = row[1]
-      Y = row[2]
+    for self.state in self.df.itertuples(index=False):    #self.df.itertuples(index=False):
+      Xs = self.state[0]
+      Xa = self.state[1]
+      Y = self.state[2]
       Xsa=(self.thetas[0])+(self.thetas[1])*(Xs)+(self.thetas[2])*(Xa)
       rho2 = (1/(1+np.exp(-Xsa)))  #prob of Y=1
       g2 = ((Xa) + 0.5*((Xa)+math.sqrt(1+(Xa)**2)))*(1-rho2) + ((Xa) - 0.5*((Xa)+math.sqrt(1+(Xa)**2)))*rho2
@@ -115,7 +115,14 @@ class DiscreteEnv(gym.Env):
     #self.horizon -= 1
     
     #depending on the value of self.state, apply a reward
-    reward = self.Ynew_cumul 
+    done = bool(self.Ynew_cumul < 0.2)    
+    reward = 0
+    
+    if done:
+      reward = self.Ynew_cumul 
+    
+  
+    
     
     #check if horion is over, otherwise keep on doing
     #if self.horizon <= 0:
@@ -130,7 +137,7 @@ class DiscreteEnv(gym.Env):
 
 #reset state and horizon    
   def reset(self):
-    self.state= self.df    #.sample(n=1, random_state=1).values.reshape(3,) 
+    self.state= self.df.sample(n=1, random_state=1).values.reshape(3,) 
     #self.horizon = 20
     return self.state
 
